gpxity package
==============

.. automodule:: gpxity
    :members:
    :undoc-members:
    :show-inheritance:

Subpackages
-----------

.. toctree::

    gpxity.backends

Submodules
----------

gpxity.track module
----------------------

.. automodule:: gpxity.track
    :members:
    :undoc-members:
    :show-inheritance:
    :exclude-members: loading, is_loading, legal_categories, append, skip_test

gpxity.auth module
------------------

.. automodule:: gpxity.auth
    :members:
    :undoc-members:
    :show-inheritance:

gpxity.backend module
---------------------

.. automodule:: gpxity.backend
    :members:
    :undoc-members:
    :show-inheritance:
    :exclude-members: append, skip_test


